# Get Started


For a very brief overview of `pydap` as a client, check this [5 minute tutorial](5_minute_tutorial.ipynb). Or you can go to the following examples

::::{grid} 1 1 1 3
:class-container: text-center
:gutter: 3

:::{grid-item-card}
:link: notebooks/ECCO
:link-type: doc
:class-header: bg-light

ECCOv4 via EarthData
^^^

```{image} https://github.com/OPENDAP/ESIP2024/blob/main/binder/img/ECCO_native.png?raw=true
:height: 200
```

:::

:::{grid-item-card}
:link: notebooks/PACE
:link-type: doc
:class-header: bg-light

PACE via EarthData
^^^

```{image} https://github.com/OPENDAP/ESIP2024/blob/main/binder/img/pace_subset.png?raw=true
:height: 200
```

:::

:::{grid-item-card}
:link: notebooks/CMIP6
:link-type: doc
:class-header: bg-light

CMIP6 via ESGF
^^^

```{image} https://github.com/OPENDAP/ESIP2024/blob/main/binder/img/Surface_Temperature.png?raw=true
:height: 200
```
:::


::::
